using System;
using System.Collections;
using System.Windows.Forms;

using SharpTools;
using SharpTools.DOM;

namespace CollectionBuilder
{

	internal class ClassLocator
	{

		#region Private member variables 

		private ArrayList classes;

		#endregion 

		#region Constructor 

		public ClassLocator()
		{
			classes = new ArrayList();
		}

		#endregion 

		#region Public static methods 

		public static ArrayList FindClasses()
		{

			// Get a reference to the currently active project
			Project active = Globals.ActiveProject;
			if( active == null )
				return new ArrayList();

			ClassLocator finder = new ClassLocator();
			
			// Iterate all ProjectItem object in the current project, adding header text to code files
			foreach( ProjectItem item in active.ProjectItems )
				finder.FindClassesForItem( item );

			ArrayList classes = finder.classes;
			classes.Sort();

			return classes;

		}

		#endregion 

		#region Private utility methods 

		private void FindClassesForItem( ProjectItem item )
		{

			if( item.SubType.ToLower() == "code" )
			{

				CodeFile code = item.CodeFile;
				if( code != null )
				{
				
					foreach( CodeClass classType in code.Classes )
					{
						Globals.OutputWindow.WriteLine( "SharpTools CollectionBuilder Plugin found class : " + classType.FullName );
						classes.Add( classType );
						System.Windows.Forms.Application.DoEvents();
					}

					foreach( CodeInterface interfaceType in code.GetChildrenOfType( typeof( CodeInterface ) ) )
					{
						Globals.OutputWindow.WriteLine( "SharpTools CollectionBuilder Plugin found interface : " + interfaceType.FullName );
						classes.Add( interfaceType );
						System.Windows.Forms.Application.DoEvents();
					}

				}

			}

			foreach( ProjectItem child in item.ProjectItems )
				FindClassesForItem( child );

		}

		#endregion 

	}

}
