using System;
using System.IO;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Data;
using System.Windows.Forms;

namespace RSSReader
{

	/// <summary>
	/// Adapts the System.Windows.Forms.Lable control to display a gradient background
	/// </summary>
	public class GradientLabel : System.Windows.Forms.Label
	{
		
		#region Private member variables 

		private Color		startColor = Color.FromArgb( 0x66, 0x99, 0xCC );
		private Color		endColor = Color.FromArgb( 0x00, 0x33, 0x99 );

		#endregion 

		public GradientLabel() : base()
		{

			// Set double-buffering to prevent flicker when drawing the control.
			SetStyle(ControlStyles.UserPaint, true);
			SetStyle(ControlStyles.AllPaintingInWmPaint, true);
			SetStyle(ControlStyles.DoubleBuffer, true);
			SetStyle(ControlStyles.Selectable, false);

		}

		#region Public properties 

		public Color StartColor
		{
			get { return startColor; }
			set { startColor = value; }
		}

		public Color EndColor
		{
			get { return endColor; }
			set { endColor = value; }
		}

		#endregion 

		private LinearGradientBrush CreateBackgroundBrush()
		{

			LinearGradientBrush backBrush = new LinearGradientBrush(
				new Point(0,0),
				new  Point(0,this.Height) ,
				startColor,
				endColor
				);   

			return backBrush;
		
		}

		protected override void OnPaint(PaintEventArgs e)
		{

			e.Graphics.SmoothingMode = SmoothingMode.AntiAlias;

			using( LinearGradientBrush backBrush = CreateBackgroundBrush() )
			{
				e.Graphics.FillRectangle( backBrush, 0, 0, this.Width, this.Height );
			}

			SizeF maxTextArea = new SizeF( this.Width - 10, this.Height );

			SizeF nameSize = e.Graphics.MeasureString( this.Text, this.Font, maxTextArea );
			RectangleF nameRect = new RectangleF(
				5,
				2,
				nameSize.Width,
				nameSize.Height
				);

			RectangleF shadowRect = new RectangleF( 
				nameRect.Left + 1,
				nameRect.Top + 1,
				nameRect.Width,
				nameRect.Height 
				);

			using( Brush brush = new SolidBrush( this.BackColor ) )
			{
				e.Graphics.DrawString( Text, Font, brush, shadowRect );
			}

			using( Brush brush = new SolidBrush( this.ForeColor ) )
			{
				e.Graphics.DrawString( Text, Font, brush, nameRect );
			}

		}


	}

}
